@@ -56,7 +56,7 @@ public class Main
       }
     catch (ClassNotFoundException e)
       {
-	File jar = new File ("%{_javadir}/jdtcore.jar");
+	File jar = new File (Config.JAR_INST_DIR + "/jdtcore.jar");
 	if (!jar.exists () || !jar.canRead ())
 	  throw e;
 
